Class: Nanoc::Filters::Terser Private

Inherits:
Nanoc::Filter
  • Object
show all
Defined in:
lib/nanoc/filters/terser.rb

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Instance Method Summary collapse

Instance Method Details

#run(content, params = {}) ⇒ String

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Runs the content through terser. This method optionally takes options to pass directly to Terser.

Parameters:

  • content (String)

    The content to filter

  • params (Hash) (defaults to: {})

    a customizable set of options

Options Hash (params):

  • :options (Array) — default: []

    A list of options to pass on to Terser

Returns:

  • (String)

    The filtered content



19
20
21
22
# File 'lib/nanoc/filters/terser.rb', line 19

def run(content, params = {})
  # Add filename to load path
  ::Terser.new(params).compile(content)
end